var structcs__les__balance__t =
[
    [ "brij", "structcs__les__balance__t.html#ad4e00f384cb0eafee0645f621d25fbd4", null ],
    [ "btui", "structcs__les__balance__t.html#a7262cbe03e4e03719735d1752b107f21", null ],
    [ "frequency_n", "structcs__les__balance__t.html#a6f2c860f3baa67bd457885718b71cbfb", null ],
    [ "i_les_balance", "structcs__les__balance__t.html#afeaddb192dbb9557488b1f9920e11308", null ],
    [ "nt_start", "structcs__les__balance__t.html#a617e788d63980aad76929c046168175e", null ],
    [ "t_start", "structcs__les__balance__t.html#a3dd28dc2f1f981a0a37bf5a67db8806b", null ],
    [ "type", "structcs__les__balance__t.html#a7aead736a07eaf25623ad7bfa1f0ee2d", null ]
];